diff --git a/src/wp-content/themes/twentyseventeen/archive.php b/src/wp-content/themes/twentyseventeen/archive.php
index 6623321353..8aa139f546 100644
--- a/src/wp-content/themes/twentyseventeen/archive.php
+++ b/src/wp-content/themes/twentyseventeen/archive.php
@@ -37,7 +37,7 @@ get_header(); ?>
* If you want to override this in a child theme, then include a file
* called content-___.php (where ___ is the Post Format name) and that will be used instead.
*/
- get_template_part( 'template-parts/post/content', get_post_format() );
+ get_template_part( 'components/post/content', get_post_format() );
endwhile;
@@ -49,7 +49,7 @@ get_header(); ?>
else :
- get_template_part( 'template-parts/post/content', 'none' );
+ get_template_part( 'components/post/content', 'none' );
endif; ?>
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/footer/footer-widgets.php b/src/wp-content/themes/twentyseventeen/components/footer/footer-widgets.php
similarity index 100%
rename from src/wp-content/themes/twentyseventeen/template-parts/footer/footer-widgets.php
rename to src/wp-content/themes/twentyseventeen/components/footer/footer-widgets.php
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/footer/site-info.php b/src/wp-content/themes/twentyseventeen/components/footer/site-info.php
similarity index 100%
rename from src/wp-content/themes/twentyseventeen/template-parts/footer/site-info.php
rename to src/wp-content/themes/twentyseventeen/components/footer/site-info.php
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/header/header-image.php b/src/wp-content/themes/twentyseventeen/components/header/header-image.php
similarity index 79%
rename from src/wp-content/themes/twentyseventeen/template-parts/header/header-image.php
rename to src/wp-content/themes/twentyseventeen/components/header/header-image.php
index 2c4b0f81dc..102456ddcc 100644
--- a/src/wp-content/themes/twentyseventeen/template-parts/header/header-image.php
+++ b/src/wp-content/themes/twentyseventeen/components/header/header-image.php
@@ -17,12 +17,12 @@
if ( ! empty( $header_image ) ) : ?>
-
+
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/header/site-branding.php b/src/wp-content/themes/twentyseventeen/components/header/site-branding.php
similarity index 100%
rename from src/wp-content/themes/twentyseventeen/template-parts/header/site-branding.php
rename to src/wp-content/themes/twentyseventeen/components/header/site-branding.php
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/navigation/navigation-top.php b/src/wp-content/themes/twentyseventeen/components/navigation/navigation-top.php
similarity index 100%
rename from src/wp-content/themes/twentyseventeen/template-parts/navigation/navigation-top.php
rename to src/wp-content/themes/twentyseventeen/components/navigation/navigation-top.php
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/page/content-front-page-panels.php b/src/wp-content/themes/twentyseventeen/components/page/content-front-page-panels.php
similarity index 97%
rename from src/wp-content/themes/twentyseventeen/template-parts/page/content-front-page-panels.php
rename to src/wp-content/themes/twentyseventeen/components/page/content-front-page-panels.php
index 9e0ffffecb..aa45a2baa3 100644
--- a/src/wp-content/themes/twentyseventeen/template-parts/page/content-front-page-panels.php
+++ b/src/wp-content/themes/twentyseventeen/components/page/content-front-page-panels.php
@@ -73,7 +73,7 @@ global $twentyseventeencounter;
have_posts() ) : $recent_posts->the_post();
- get_template_part( 'template-parts/post/content', 'excerpt' );
+ get_template_part( 'components/post/content', 'excerpt' );
endwhile;
wp_reset_postdata();
?>
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/page/content-front-page.php b/src/wp-content/themes/twentyseventeen/components/page/content-front-page.php
similarity index 100%
rename from src/wp-content/themes/twentyseventeen/template-parts/page/content-front-page.php
rename to src/wp-content/themes/twentyseventeen/components/page/content-front-page.php
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/page/content-page.php b/src/wp-content/themes/twentyseventeen/components/page/content-page.php
similarity index 100%
rename from src/wp-content/themes/twentyseventeen/template-parts/page/content-page.php
rename to src/wp-content/themes/twentyseventeen/components/page/content-page.php
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/post/content-audio.php b/src/wp-content/themes/twentyseventeen/components/post/content-audio.php
similarity index 100%
rename from src/wp-content/themes/twentyseventeen/template-parts/post/content-audio.php
rename to src/wp-content/themes/twentyseventeen/components/post/content-audio.php
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/post/content-excerpt.php b/src/wp-content/themes/twentyseventeen/components/post/content-excerpt.php
similarity index 100%
rename from src/wp-content/themes/twentyseventeen/template-parts/post/content-excerpt.php
rename to src/wp-content/themes/twentyseventeen/components/post/content-excerpt.php
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/post/content-gallery.php b/src/wp-content/themes/twentyseventeen/components/post/content-gallery.php
similarity index 100%
rename from src/wp-content/themes/twentyseventeen/template-parts/post/content-gallery.php
rename to src/wp-content/themes/twentyseventeen/components/post/content-gallery.php
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/post/content-image.php b/src/wp-content/themes/twentyseventeen/components/post/content-image.php
similarity index 100%
rename from src/wp-content/themes/twentyseventeen/template-parts/post/content-image.php
rename to src/wp-content/themes/twentyseventeen/components/post/content-image.php
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/post/content-none.php b/src/wp-content/themes/twentyseventeen/components/post/content-none.php
similarity index 100%
rename from src/wp-content/themes/twentyseventeen/template-parts/post/content-none.php
rename to src/wp-content/themes/twentyseventeen/components/post/content-none.php
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/post/content-video.php b/src/wp-content/themes/twentyseventeen/components/post/content-video.php
similarity index 100%
rename from src/wp-content/themes/twentyseventeen/template-parts/post/content-video.php
rename to src/wp-content/themes/twentyseventeen/components/post/content-video.php
diff --git a/src/wp-content/themes/twentyseventeen/template-parts/post/content.php b/src/wp-content/themes/twentyseventeen/components/post/content.php
similarity index 100%
rename from src/wp-content/themes/twentyseventeen/template-parts/post/content.php
rename to src/wp-content/themes/twentyseventeen/components/post/content.php
diff --git a/src/wp-content/themes/twentyseventeen/footer.php b/src/wp-content/themes/twentyseventeen/footer.php
index 2d72029b00..e911c1a7da 100644
--- a/src/wp-content/themes/twentyseventeen/footer.php
+++ b/src/wp-content/themes/twentyseventeen/footer.php
@@ -19,7 +19,7 @@
diff --git a/src/wp-content/themes/twentyseventeen/header.php b/src/wp-content/themes/twentyseventeen/header.php
index dc173d67e8..f76bbf379a 100644
--- a/src/wp-content/themes/twentyseventeen/header.php
+++ b/src/wp-content/themes/twentyseventeen/header.php
@@ -28,12 +28,12 @@
diff --git a/src/wp-content/themes/twentyseventeen/front-page.php b/src/wp-content/themes/twentyseventeen/front-page.php
index 555688857b..ea4ddc996d 100644
--- a/src/wp-content/themes/twentyseventeen/front-page.php
+++ b/src/wp-content/themes/twentyseventeen/front-page.php
@@ -20,10 +20,10 @@ get_header(); ?>
$panels = array( '1', '2', '3', '4' );
$titles = array();
- global $twentyseventeencounter; // Used in template-parts/page/content-front-page-panels.php file.
+ global $twentyseventeencounter; // Used in components/page/content-front-page-panels.php file.
if ( 0 !== twentyseventeen_panel_count() || is_customize_preview() ) : // If we have pages to show.
@@ -44,7 +44,7 @@ get_header(); ?>
set_query_var( 'panel', $panel );
$titles[] = get_the_title(); // Put page titles in an array for use in navigation.
- get_template_part( 'template-parts/page/content', 'front-page-panels' );
+ get_template_part( 'components/page/content', 'front-page-panels' );
wp_reset_postdata();
else :